Module: OllamaAgent::Agent::SessionWiring
- Included in:
- OllamaAgent::Agent
- Defined in:
- lib/ollama_agent/agent/session_wiring.rb
Overview
Session resume/save and tool message formatting for the chat transcript.
Session resume/save and tool message formatting for the chat transcript.