Module: OllamaAgent::ToolRuntime::PlanExtractor
- Included in:
- OllamaJsonPlanner
- Defined in:
- lib/ollama_agent/tool_runtime/plan_extractor.rb
Overview
Strategy protocol for Loop: produce the next plan hash from context and memory.
Strategy protocol for Loop: produce the next plan hash from context and memory.